raytraverse.evaluate
==========================================================

MetricSet
---------------------------------

.. autoclass:: raytraverse.evaluate.MetricSet
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

PositionIndex
---------------------------------

.. autoclass:: raytraverse.evaluate.PositionIndex
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

retina
-------

.. automodule:: raytraverse.evaluate.retina
    :members:
    :undoc-members:
    :show-inheritance:
